==> doxygen-docs-1.14.0-3-x86_64.pkg.tar.zst: usr/share/doc/doxygen/html/search/pages_10.js <==
var searchData=
[
  ['favorite_20programming_20language_20is_20x_20can_20i_20still_20use_20doxygen_0',['My favorite programming language is X. Can I still use Doxygen?',['../faq.html#faq_pgm_X',1,'']]],
  ['features_1',['Features',['../features.html',1,'']]],
  ['fenced_20code_20blocks_2',['Fenced Code Blocks',['../markdown.html#md_fenced',1,'']]],
  ['file_3',['file',['../starting.html#step1',1,'Step 1: Creating a configuration file'],['../faq.html#faq_html_header',1,'The overall HTML output looks different, while I only wanted to use my own html header file']]],
  ['file_20menu_4',['File menu',['../doxywizard_usage.html#dw_menu_file',1,'']]],
  ['file_20namespace_20are_20not_20documented_5',['Help, some/all of the members of my class / file / namespace are not documented?',['../faq.html#fac_al',1,'']]],
  ['file_20with_20a_20custom_20extension_20is_20not_20parsed_20properly_20anymore_6',['My file with a custom extension is not parsed (properly) (anymore).',['../faq.html#faq_ext_mapping',1,'']]],
  ['files_7',['Automatically Adding Files',['../additional.html#automatically_adding_files',1,'']]],
  ['files_8',['files',['../config.html#config_input',1,'Configuration options related to the input files'],['../autolink.html#linkfile',1,'Links to files']]],
  ['files_20as_20pages_9',['Including Markdown files as pages',['../markdown.html#md_page_header',1,'']]],
  ['files_20in_20combination_20with_20compressed_20html_10',['How can I use tag files in combination with compressed HTML?',['../faq.html#faq_chm',1,'']]],
  ['fine_20tuning_20the_20output_11',['Fine-tuning the output',['../doxygen_usage.html#doxygen_finetune',1,'']]],
  ['flow_20chart_12',['\vhdlflow [(title for the flow chart)]',['../commands.html#cmdvhdlflow',1,'']]],
  ['footer_20and_20stylesheet_20changes_13',['Header, Footer, and Stylesheet changes',['../customize.html#minor_tweaks_header_css',1,'']]],
  ['for_20c_20like_20languages_20c_20c_20c_20objective_20c_20php_20java_14',['Comment blocks for C-like languages (C/C++/C#/Objective-C/PHP/Java)',['../docblocks.html#cppblock',1,'']]],
  ['for_20github_20alerts_15',['Support for GitHub Alerts',['../markdown.html#mddox_github_alerts',1,'']]],
  ['for_20the_20autogen_20definitions_20output_16',['Configuration options for the AutoGen Definitions output',['../config.html#config_autogen',1,'']]],
  ['for_20the_20flow_20chart_17',['\vhdlflow [(title for the flow chart)]',['../commands.html#cmdvhdlflow',1,'']]],
  ['format_18',['Format',['../config.html#config_format',1,'']]],
  ['format_19',['format',['../perlmod.html#doxydocs_format',1,'Documentation format.'],['../extsearch.html#extsearch_api_index',1,'Indexer input format'],['../extsearch.html#extsearch_api_search_out',1,'Search results format'],['../extsearch.html#extsearch_api_search_in',1,'Search URL format']]],
  ['formats_20',['Output Formats',['../output.html',1,'']]],
  ['formulas_21',['Including formulas',['../formulas.html',1,'']]],
  ['fortran_22',['Comment blocks in Fortran',['../docblocks.html#fortranblocks',1,'']]],
  ['fragment_23',['How can I make Doxygen ignore some code fragment?',['../faq.html#faq_code',1,'']]],
  ['frequently_20asked_20questions_24',['Frequently Asked Questions',['../faq.html',1,'']]],
  ['from_20my_20directory_20tree_25',['How can I exclude all test directories from my directory tree?',['../faq.html#faq_excl_dir',1,'']]],
  ['from_20source_20on_20unix_26',['Compiling from source on UNIX',['../install.html#install_src_unix',1,'']]],
  ['from_20source_20on_20windows_27',['Compiling from source on Windows',['../install.html#install_src_windows',1,'']]],
  ['from_20the_20command_20line_28',['Can I configure Doxygen from the command line?',['../faq.html#faq_cmdline',1,'']]],
  ['function_20declaration_29',['function declaration',['../commands.html#cmdfn',1,'\fn (function declaration)'],['../commands.html#cmdoverload',1,'\overload [(function declaration)]']]],
  ['functions_30',['Links to functions',['../autolink.html#linkfunc',1,'']]],
  ['functions_20are_20shown_20in_20the_20documentation_31',['When I set EXTRACT_ALL to NO none of my functions are shown in the documentation.',['../faq.html#faq_extract_all',1,'']]]
];

==> doxygen-docs-1.15.0-1-x86_64.pkg.tar.zst: usr/share/doc/doxygen/html/search/pages_10.js <==
var searchData=
[
  ['favorite_20programming_20language_20is_20x_20can_20i_20still_20use_20doxygen_0',['My favorite programming language is X. Can I still use Doxygen?',['../faq.html#faq_pgm_X',1,'']]],
  ['features_1',['Features',['../features.html',1,'']]],
  ['fenced_20code_20blocks_2',['Fenced Code Blocks',['../markdown.html#md_fenced',1,'']]],
  ['file_3',['file',['../starting.html#step1',1,'Step 1: Creating a configuration file'],['../faq.html#faq_html_header',1,'The overall HTML output looks different, while I only wanted to use my own html header file']]],
  ['file_20menu_4',['File menu',['../doxywizard_usage.html#dw_menu_file',1,'']]],
  ['file_20namespace_20are_20not_20documented_5',['Help, some/all of the members of my class / file / namespace are not documented?',['../faq.html#fac_al',1,'']]],
  ['file_20with_20a_20custom_20extension_20is_20not_20parsed_20properly_20anymore_6',['My file with a custom extension is not parsed (properly) (anymore).',['../faq.html#faq_ext_mapping',1,'']]],
  ['files_7',['Automatically Adding Files',['../additional.html#automatically_adding_files',1,'']]],
  ['files_8',['files',['../config.html#config_input',1,'Configuration options related to the input files'],['../autolink.html#linkfile',1,'Links to files']]],
  ['files_20as_20pages_9',['Including Markdown files as pages',['../markdown.html#md_page_header',1,'']]],
  ['files_20in_20combination_20with_20compressed_20html_10',['How can I use tag files in combination with compressed HTML?',['../faq.html#faq_chm',1,'']]],
  ['fine_20tuning_20the_20output_11',['Fine-tuning the output',['../doxygen_usage.html#doxygen_finetune',1,'']]],
  ['flow_20chart_12',['\\vhdlflow [(title for the flow chart)]',['../commands.html#cmdvhdlflow',1,'']]],
  ['footer_20and_20stylesheet_20changes_13',['Header, Footer, and Stylesheet changes',['../customize.html#minor_tweaks_header_css',1,'']]],
  ['for_20c_20like_20languages_20c_20c_20c_20objective_20c_20php_20java_14',['Comment blocks for C-like languages (C/C++/C#/Objective-C/PHP/Java)',['../docblocks.html#cppblock',1,'']]],
  ['for_20github_20alerts_15',['Support for GitHub Alerts',['../markdown.html#mddox_github_alerts',1,'']]],
  ['for_20the_20autogen_20definitions_20output_16',['Configuration options for the AutoGen Definitions output',['../config.html#config_autogen',1,'']]],
  ['for_20the_20flow_20chart_17',['\\vhdlflow [(title for the flow chart)]',['../commands.html#cmdvhdlflow',1,'']]],
  ['format_18',['Format',['../config.html#config_format',1,'']]],
  ['format_19',['format',['../perlmod.html#doxydocs_format',1,'Documentation format.'],['../extsearch.html#extsearch_api_index',1,'Indexer input format'],['../extsearch.html#extsearch_api_search_out',1,'Search results format'],['../extsearch.html#extsearch_api_search_in',1,'Search URL format']]],
  ['formats_20',['Output Formats',['../output.html',1,'']]],
  ['formulas_21',['Including formulas',['../formulas.html',1,'']]],
  ['fortran_22',['Comment blocks in Fortran',['../docblocks.html#fortranblocks',1,'']]],
  ['fragment_23',['How can I make Doxygen ignore some code fragment?',['../faq.html#faq_code',1,'']]],
  ['frequently_20asked_20questions_24',['Frequently Asked Questions',['../faq.html',1,'']]],
  ['from_20my_20directory_20tree_25',['How can I exclude all test directories from my directory tree?',['../faq.html#faq_excl_dir',1,'']]],
  ['from_20source_20on_20unix_26',['Compiling from source on UNIX',['../install.html#install_src_unix',1,'']]],
  ['from_20source_20on_20windows_27',['Compiling from source on Windows',['../install.html#install_src_windows',1,'']]],
  ['from_20the_20command_20line_28',['Can I configure Doxygen from the command line?',['../faq.html#faq_cmdline',1,'']]],
  ['function_20declaration_29',['function declaration',['../commands.html#cmdfn',1,'\\fn (function declaration)'],['../commands.html#cmdoverload',1,'\\overload [(function declaration)]']]],
  ['functions_30',['Links to functions',['../autolink.html#linkfunc',1,'']]],
  ['functions_20are_20shown_20in_20the_20documentation_31',['When I set EXTRACT_ALL to NO none of my functions are shown in the documentation.',['../faq.html#faq_extract_all',1,'']]]
];
